@@ -43,6 +43,12 @@ class DataFrame:
         super(DataFrame, self).__setattr__('ncol', 0)
         super(DataFrame, self).__setattr__('nrow', 0)
         super(DataFrame, self).__setattr__('shape', (0,0))
+    def __repr__(self):
+        df = DataFrame.to_pandas(self)
+        return df.__repr__()
+    def __str__(self):
+        df = DataFrame.to_pandas(self)
+        return df.__repr__()
     def __getattr__(self, key):        
         return self.d[key]
     def __setattr__(self, name, value):
@@ -56,37 +62,34 @@ class DataFrame:
     def __getitem__(self,args):
         if type(args) == tuple:
             rows,key=args
-            if len(key) == 1:
-                if type(key) == list:
-                    t_ = DataFrame()
-                    for k in key:
-                        DataFrame.__setattr__(t_,k,self.d[k][rows])
-                    return t_
-                else:
-                    return self.d[key][rows]
+            if type(key) == str:
+                return self.d[key][rows]
             else:
-                t_ = DataFrame()
-                for k in key:
-                    DataFrame.__setattr__(t_,k,self.d[k][rows])
-                return t_
+                if type(key) == list or type(key) == np.array:                    
+                        t_ = DataFrame()
+                        for k in key:
+                            if type(k) == int:
+                                k = list(self.d.keys())[k]
+                            DataFrame.__setattr__(t_,k,self.d[k][rows])
+                        return t_
+                elif type(key) == int:
+                    k = list(self.d.keys())[key]
+                    return self.d[k][rows]
         else:
             key = args
             if type(key) == str:
                 return self.d[key]
             else:
-                if len(key) == 1:
-                    if type(key) == list:
+                if type(key) == list or type(key) == np.array:                    
                         t_ = DataFrame()
                         for k in key:
+                            if type(k) == int:
+                                k = list(self.d.keys())[k]
                             DataFrame.__setattr__(t_,k,self.d[k])
                         return t_
-                    else:
-                        return self.d[key]
-                else:
-                    t_ = DataFrame()
-                    for k in key:
-                        DataFrame.__setattr__(t_,k,self.d[k])
-                    return t_
+                elif type(key) == int:
+                    k = list(self.d.keys())[key]
+                    return self.d[k]
     def __setitem__(self,key,values):
         DataFrame.__setattr__(self,key,values)
 
